==> charlatan_0.5.0.tar.gz: charlatan/R/person-provider-ko_KR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/ko_KR/__init__.py

person_formats_ko_kr = c(
  '{{first_names}}{{last_names}}',
  '{{first_names}}{{last_names1}}{{last_names2}}'
)

person_first_names_ko_kr = c(
  "\uae40",
  "\uc774",
  "\ucd5c",
  "\ubc15",
  "\uc815",
  "\uac15",
  "\uc870",
  "\uc724",
  "\uc7a5",
  "\uc784",
  "\uc624",
  "\ud55c",
  "\uc2e0",
  "\uc11c",
  "\uad8c",
  "\ud669",
  "\uc548",
  "\uc1a1",
  "\ub958",
  "\ud64d",
  "\uc804",
  "\uace0",
  "\ubb38",
  "\uc190",
  "\uc591",
  "\ubc30",
  "\uc870",
  "\ubc31",
  "\ud5c8",
  "\ub0a8",
  "\uc2ec",
  "\uc720",
  "\ub178",
  "\ud558",
  "\uc804",
  "\uc815",
  "\uacfd",
  "\uc131",
  "\ucc28",
  "\uc720",
  "\uad6c",
  "\uc6b0",
  "\uc8fc",
  "\uc784",
  "\ub098",
  "\uc2e0",
  "\ubbfc",
  "\uc9c4",
  "\uc9c0",
  "\uc5c4",
  "\uc6d0",
  "\ucc44",
  "\ucc9c",
  "\uc591",
  "\uacf5",
  "\ud604",
  "\ubc29",
  "\ud568",
  "\uc5fc",
  "\uc5ec",
  "\ucd94",
  "\ubcc0",
  "\ub3c4",
  "\uc11d",
  "\uc18c",
  "\uc120",
  "\uc124",
  "\ubc29",
  "\ub9c8",
  "\uae38",
  "\uc704",
  "\uc5f0",
  "\uba85",
  "\uae30",
  "\uae08",
  "\uc655",
  "\ubc18",
  "\uc625",
  "\uc721",
  "\uc9c4",
  "\uc778",
  "\ub9f9",
  "\uc81c",
  "\ud0c1",
  "\ubaa8",
  "\ub0a8\uad81",
  "\uc5b4",
  "\uc6a9",
  "\ud3b8",
  "\ubd09",
  "\uad6c",
  "\uc608",
  "\uacbd",
  "\uc0ac",
  "\ubd80",
  "\ud669\ubcf4",
  "\uac00",
  "\ubcf5",
  "\uacc4",
  "\uc81c\uac08",
  "\uc0ac\uacf5",
  "\uc120\uc6b0",
  "\ud33d",
  "\uacac",
  "\uc885",
  "\uc2b9",
  "\ub3c5\uace0",
  "\uc639",
  "\ube59",
  "\uc7a5",
  "\ucd94",
  "\ud3b8",
  "\uc544",
  "\uc810",
  "\ud765",
  "\ub0ad",
  "\ud574",
  "\ud310",
  "\ucd08",
  "\ud544",
  "\uad89",
  "\uadfc",
  "\ub9e4",
  "\ub3d9\ubc29",
  "\ud638",
  "\ub450",
  "\ubbf8",
  "\uc694",
  "\uc57c",
  "\ubb35",
  "\uc790",
  "\ub9cc",
  "\uc6b4",
  "\ud658",
  "\ubc94",
  "\ucc3d",
  "\uc5fd",
  "\uc218",
  "\uc560",
  "\ub2e8",
  "\uc21c",
  "\ub3c8",
  "\uc900",
  "\ubb18",
  "\ub2f4",
  "\uc7a5\uace1",
  "\uc5b4\uae08",
  "\uac15\uc804",
  "\uc0bc",
  "\uc800",
  "\uad70",
  "\uad50",
  "\uc601",
  "\ud6c4",
  "\ub204",
  "\uc18c\ubd09",
  "\ub1cc",
  "\ub9dd\uc808",
  "\uc6d0",
  "\uc999",
  "\uc99d"
)

person_last_names_ko_kr = c(
  "\uc7ac",
  "\uc6b0",
  "\uc9c0",
  "\ud658",
  "\ud604",
  "\uc6c5",
  "\uadfc",
  "\ucca0",
  "\ubbfc",
  "\uc815",
  "\ud76c",
  "\uc131",
  "\uc8fc",
  "\ub2e4",
  "\ub824",
  "\ube48",
  "\uc601",
  "\uc900",
  "\uc9c4",
  "\ud601",
  "\uc218",
  "\ub300",
  "\ud638",
  "\ud5a5",
  "\uc5f4",
  "\uc21c",
  "\ubbf8",
  "\uc5f0",
  "\uc720",
  "\ub9ac",
  "\ud6c8",
  "\uc775",
  "\ud61c",
  "\uc740",
  "\ud718",
  "\ubc94",
  "\ub450",
  "\ud0dc",
  "\ud669",
  "\uacbd",
  "\ud1b5",
  "\uc6d0",
  "\ud558",
  "\uac00",
  "\ub78c",
  "\uc120",
  "\uad00",
  "\ub828",
  "\ubcf4",
  "\uc885",
  "\uc18c",
  "\uc608",
  "\uc11d",
  "\ud798",
  "\ucc2c",
  "\uc2b9",
  "\uc0c1",
  "\ud55c",
  "\ubcc4",
  "\ud64d",
  "\uc6a9",
  "\uc544",
  "\ub355",
  "\uade0",
  "\uc758",
  "\ud6c4",
  "\uad6c",
  "\ud615",
  "\uaddc",
  "\uc548",
  "\uac15",
  "\uc0b0",
  "\uba85",
  "\uc138",
  "\ud6a8",
  "\ubb34",
  "\ud611",
  "\uae30",
  "\uc5b5",
  "\ub3d9",
  "\uc644",
  "\uc724",
  "\ucc3d",
  "\ub3c4",
  "\uc704",
  "\uc5fd",
  "\uc628",
  "\uad8c",
  "\ubcd1",
  "\uc6b1",
  "\ube44",
  "\ud654",
  "\uc2ac",
  "\uc1a1",
  "\uad11",
  "\ub0a8",
  "\uc778",
  "\ud574",
  "\uc591",
  "\ub9bc",
  "\ub780",
  "\uac74",
  "\uc194",
  "\uae08"
)

person_ko_kr <- list(
  first_names = person_first_names_ko_kr,
  last_names = person_last_names_ko_kr
)

==> charlatan_0.5.1.tar.gz: charlatan/R/person-provider-ko_KR.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/ko_KR/__init__.py

person_formats_ko_kr <- c(
  "{{first_names}}{{last_names}}",
  "{{first_names}}{{last_names1}}{{last_names2}}"
)

person_first_names_ko_kr <- c(
  "\uae40",
  "\uc774",
  "\ucd5c",
  "\ubc15",
  "\uc815",
  "\uac15",
  "\uc870",
  "\uc724",
  "\uc7a5",
  "\uc784",
  "\uc624",
  "\ud55c",
  "\uc2e0",
  "\uc11c",
  "\uad8c",
  "\ud669",
  "\uc548",
  "\uc1a1",
  "\ub958",
  "\ud64d",
  "\uc804",
  "\uace0",
  "\ubb38",
  "\uc190",
  "\uc591",
  "\ubc30",
  "\uc870",
  "\ubc31",
  "\ud5c8",
  "\ub0a8",
  "\uc2ec",
  "\uc720",
  "\ub178",
  "\ud558",
  "\uc804",
  "\uc815",
  "\uacfd",
  "\uc131",
  "\ucc28",
  "\uc720",
  "\uad6c",
  "\uc6b0",
  "\uc8fc",
  "\uc784",
  "\ub098",
  "\uc2e0",
  "\ubbfc",
  "\uc9c4",
  "\uc9c0",
  "\uc5c4",
  "\uc6d0",
  "\ucc44",
  "\ucc9c",
  "\uc591",
  "\uacf5",
  "\ud604",
  "\ubc29",
  "\ud568",
  "\uc5fc",
  "\uc5ec",
  "\ucd94",
  "\ubcc0",
  "\ub3c4",
  "\uc11d",
  "\uc18c",
  "\uc120",
  "\uc124",
  "\ubc29",
  "\ub9c8",
  "\uae38",
  "\uc704",
  "\uc5f0",
  "\uba85",
  "\uae30",
  "\uae08",
  "\uc655",
  "\ubc18",
  "\uc625",
  "\uc721",
  "\uc9c4",
  "\uc778",
  "\ub9f9",
  "\uc81c",
  "\ud0c1",
  "\ubaa8",
  "\ub0a8\uad81",
  "\uc5b4",
  "\uc6a9",
  "\ud3b8",
  "\ubd09",
  "\uad6c",
  "\uc608",
  "\uacbd",
  "\uc0ac",
  "\ubd80",
  "\ud669\ubcf4",
  "\uac00",
  "\ubcf5",
  "\uacc4",
  "\uc81c\uac08",
  "\uc0ac\uacf5",
  "\uc120\uc6b0",
  "\ud33d",
  "\uacac",
  "\uc885",
  "\uc2b9",
  "\ub3c5\uace0",
  "\uc639",
  "\ube59",
  "\uc7a5",
  "\ucd94",
  "\ud3b8",
  "\uc544",
  "\uc810",
  "\ud765",
  "\ub0ad",
  "\ud574",
  "\ud310",
  "\ucd08",
  "\ud544",
  "\uad89",
  "\uadfc",
  "\ub9e4",
  "\ub3d9\ubc29",
  "\ud638",
  "\ub450",
  "\ubbf8",
  "\uc694",
  "\uc57c",
  "\ubb35",
  "\uc790",
  "\ub9cc",
  "\uc6b4",
  "\ud658",
  "\ubc94",
  "\ucc3d",
  "\uc5fd",
  "\uc218",
  "\uc560",
  "\ub2e8",
  "\uc21c",
  "\ub3c8",
  "\uc900",
  "\ubb18",
  "\ub2f4",
  "\uc7a5\uace1",
  "\uc5b4\uae08",
  "\uac15\uc804",
  "\uc0bc",
  "\uc800",
  "\uad70",
  "\uad50",
  "\uc601",
  "\ud6c4",
  "\ub204",
  "\uc18c\ubd09",
  "\ub1cc",
  "\ub9dd\uc808",
  "\uc6d0",
  "\uc999",
  "\uc99d"
)

person_last_names_ko_kr <- c(
  "\uc7ac",
  "\uc6b0",
  "\uc9c0",
  "\ud658",
  "\ud604",
  "\uc6c5",
  "\uadfc",
  "\ucca0",
  "\ubbfc",
  "\uc815",
  "\ud76c",
  "\uc131",
  "\uc8fc",
  "\ub2e4",
  "\ub824",
  "\ube48",
  "\uc601",
  "\uc900",
  "\uc9c4",
  "\ud601",
  "\uc218",
  "\ub300",
  "\ud638",
  "\ud5a5",
  "\uc5f4",
  "\uc21c",
  "\ubbf8",
  "\uc5f0",
  "\uc720",
  "\ub9ac",
  "\ud6c8",
  "\uc775",
  "\ud61c",
  "\uc740",
  "\ud718",
  "\ubc94",
  "\ub450",
  "\ud0dc",
  "\ud669",
  "\uacbd",
  "\ud1b5",
  "\uc6d0",
  "\ud558",
  "\uac00",
  "\ub78c",
  "\uc120",
  "\uad00",
  "\ub828",
  "\ubcf4",
  "\uc885",
  "\uc18c",
  "\uc608",
  "\uc11d",
  "\ud798",
  "\ucc2c",
  "\uc2b9",
  "\uc0c1",
  "\ud55c",
  "\ubcc4",
  "\ud64d",
  "\uc6a9",
  "\uc544",
  "\ub355",
  "\uade0",
  "\uc758",
  "\ud6c4",
  "\uad6c",
  "\ud615",
  "\uaddc",
  "\uc548",
  "\uac15",
  "\uc0b0",
  "\uba85",
  "\uc138",
  "\ud6a8",
  "\ubb34",
  "\ud611",
  "\uae30",
  "\uc5b5",
  "\ub3d9",
  "\uc644",
  "\uc724",
  "\ucc3d",
  "\ub3c4",
  "\uc704",
  "\uc5fd",
  "\uc628",
  "\uad8c",
  "\ubcd1",
  "\uc6b1",
  "\ube44",
  "\ud654",
  "\uc2ac",
  "\uc1a1",
  "\uad11",
  "\ub0a8",
  "\uc778",
  "\ud574",
  "\uc591",
  "\ub9bc",
  "\ub780",
  "\uac74",
  "\uc194",
  "\uae08"
)

person_ko_kr <- list(
  first_names = person_first_names_ko_kr,
  last_names = person_last_names_ko_kr
)
